pub struct Queue {
pub path: PathBuf,
}Fields
path: PathBufImplementations
Sourceimpl Queue
impl Queue
pub fn new(path: PathBuf) -> Self
Sourcepub fn push(
&self,
sources: Vec<Source>,
title: Option<String>,
metadata: Value,
session_id: Option<String>,
blocked_by: Vec<String>,
) -> Result<Item>
pub fn push( &self, sources: Vec<Source>, title: Option<String>, metadata: Value, session_id: Option<String>, blocked_by: Vec<String>, ) -> Result<Item>
Add a new item to the queue. Returns the created Item.
Sourcepub fn push_with_description(
&self,
sources: Vec<Source>,
title: Option<String>,
description: Option<String>,
metadata: Value,
session_id: Option<String>,
blocked_by: Vec<String>,
) -> Result<Item>
pub fn push_with_description( &self, sources: Vec<Source>, title: Option<String>, description: Option<String>, metadata: Value, session_id: Option<String>, blocked_by: Vec<String>, ) -> Result<Item>
Add a new item to the queue with description support.
Sourcepub fn push_many_with_description(
&self,
items: Vec<NewItem>,
) -> Result<Vec<Item>>
pub fn push_many_with_description( &self, items: Vec<NewItem>, ) -> Result<Vec<Item>>
Add many new items to the queue under a single lock.
Sourcepub fn ready(&self) -> Vec<Item>
pub fn ready(&self) -> Vec<Item>
Return pending items that are not blocked by any pending item.